<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="uk">
<context>
    <name>ColorLabel</name>
    <message>
        <location filename="../colorLabel.cpp" line="37"/>
        <source>Click to change color</source>
        <translation>Клацніть, щоб змінити колір</translation>
    </message>
    <message>
        <location filename="../colorLabel.cpp" line="61"/>
        <source>Select Color</source>
        <translation>Вибрати колір</translation>
    </message>
</context>
<context>
    <name>ConfigOtherToolKits</name>
    <message>
        <location filename="../configothertoolkits.cpp" line="178"/>
        <source>GTK themes</source>
        <translation>Теми GTK</translation>
    </message>
    <message>
        <location filename="../configothertoolkits.cpp" line="179"/>
        <source>&lt;p&gt;&apos;%1&apos; has been overwritten.&lt;/p&gt;&lt;p&gt;You can find a copy of your old settings in &apos;%2&apos;&lt;/p&gt;</source>
        <translation>&lt;p&gt;&apos;%1&apos; було перевизначено.&lt;/p&gt;&lt;p&gt;Ви можете знайти копію старих налаштувань у &apos;%2&apos;&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../configothertoolkits.cpp" line="244"/>
        <source>Error</source>
        <translation>Помилка</translation>
    </message>
    <message>
        <location filename="../configothertoolkits.cpp" line="244"/>
        <source>Error: gsettings cannot be run</source>
        <translation>Помилка: не вдалося запустити gsettings</translation>
    </message>
</context>
<context>
    <name>FontsConfig</name>
    <message>
        <location filename="../fontsconfig.ui" line="23"/>
        <source>Font</source>
        <translation>Шрифт</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="30"/>
        <source>Default font for user interface</source>
        <translation>Типовий шрифт інтерфейсу користувача</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="36"/>
        <source>Font name:</source>
        <translation>Назва шрифту:</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="46"/>
        <source>Style:</source>
        <translation>Стиль:</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="77"/>
        <source>Point size:</source>
        <translation>Розмір крапки:</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="54"/>
        <source>Normal</source>
        <translation>Звичайний</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="59"/>
        <source>Bold</source>
        <translation>Жирний</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="64"/>
        <source>Italic</source>
        <translation>Курсив</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="69"/>
        <source>Bold Italic</source>
        <translation>Жирний курсив</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="94"/>
        <source>The following settings only affect newly started applications</source>
        <translation>Наступні налаштування вплинуть тільки на щойно запущені програми</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="100"/>
        <source>Use antialias fonts</source>
        <translation>Використовувати шрифти зі згладжуванням</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="153"/>
        <source>Font hinting style:</source>
        <translation>Стиль хінтингу шрифтів:</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="211"/>
        <source>Monospace:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="118"/>
        <location filename="../fontsconfig.ui" line="164"/>
        <source>None</source>
        <translation>Вимкнено</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="169"/>
        <source>Slight</source>
        <translation>Незначно</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="174"/>
        <source>Medium</source>
        <translation>Середньо</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="179"/>
        <source>Full</source>
        <translation>Повністю</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="146"/>
        <source>Font hinting</source>
        <translation>Хінтинг шрифтів</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="187"/>
        <source>Resolution (DPI):</source>
        <translation>Роздільна здатність (DPI):</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="204"/>
        <source>Autohint</source>
        <translation>Автохінтинг</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="107"/>
        <source>Subpixel antialiasing:</source>
        <translation>Згладжування субпікселів:</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="123"/>
        <source>RGB</source>
        <translation>RGB</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="128"/>
        <source>BGR</source>
        <translation>BGR</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="133"/>
        <source>VRGB</source>
        <translation>VRGB</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="138"/>
        <source>VBGR</source>
        <translation>VBGR</translation>
    </message>
</context>
<context>
    <name>GTKConfig</name>
    <message>
        <location filename="../gtkconfig.ui" line="56"/>
        <source>GTK Style</source>
        <translation>GTK-стиль</translation>
    </message>
    <message>
        <location filename="../gtkconfig.ui" line="75"/>
        <source>Set GTK themes (GTK configuration files will be overwritten!)</source>
        <translation>Встановити теми GTK (файли налаштувань GTK буде замінено)</translation>
    </message>
    <message>
        <location filename="../gtkconfig.ui" line="105"/>
        <source>GTK 3 Theme:</source>
        <translation>Тема GTK 3:</translation>
    </message>
    <message>
        <location filename="../gtkconfig.ui" line="89"/>
        <source>GTK 2 Theme:</source>
        <translation>Тема GTK 2:</translation>
    </message>
    <message>
        <location filename="../gtkconfig.ui" line="117"/>
        <source>To attempt uniform theming, either select similar style/theme (if available) across all lists, or select &apos;gtk2&apos; Qt style (if available) to mimic GTK themes.

Make sure &apos;xsettingsd&apos; is installed to help GTK applications apply themes on the fly.</source>
        <translation>Щоб спробувати уніфікувати вигляд, виберіть або схожий стиль/тему (якщо доступні) в усіх списках, або виберіть стиль «gtk2» для Qt (якщо доступний), щоб імітувати теми GTK.

Переконайтеся, що встановлено &apos;xsettingsd&apos;, щоб допомогти програмам GTK застосовувати теми «на льоту».</translation>
    </message>
</context>
<context>
    <name>IconThemeConfig</name>
    <message>
        <location filename="../iconthemeconfig.ui" line="14"/>
        <source>LXQt Appearance Configuration</source>
        <translation>Налаштування вигляду LXQt</translation>
    </message>
    <message>
        <location filename="../iconthemeconfig.ui" line="26"/>
        <source>Icons Theme</source>
        <translation>Тема піктограм</translation>
    </message>
    <message>
        <location filename="../iconthemeconfig.ui" line="87"/>
        <source>The KDE extension of XDG icon themes -&gt; FollowsColorScheme</source>
        <translation>Розширення KDE теми піктограм XDG -&gt; FollowsColorScheme</translation>
    </message>
    <message>
        <location filename="../iconthemeconfig.ui" line="90"/>
        <source>Colorize icons based on widget style (palette)</source>
        <translation>Забарвлювати піктограми на основі стилю віджета (палітра)</translation>
    </message>
</context>
<context>
    <name>LXQtThemeConfig</name>
    <message>
        <location filename="../lxqtthemeconfig.ui" line="23"/>
        <source>LXQt Theme</source>
        <translation>Тема LXQt</translation>
    </message>
    <message>
        <location filename="../lxqtthemeconfig.ui" line="57"/>
        <source>Use wallpaper provided by theme</source>
        <translation>Використовувати шпалери теми</translation>
    </message>
    <message>
        <location filename="../lxqtthemeconfig.ui" line="64"/>
        <source>Use palette provided by theme</source>
        <translation>Використовувати палітру, яка відповідає темі</translation>
    </message>
    <message>
        <location filename="../lxqtthemeconfig.cpp" line="83"/>
        <source>(User Theme)</source>
        <translation>(Користувацька тема)</translation>
    </message>
    <message>
        <location filename="../lxqtthemeconfig.cpp" line="188"/>
        <source>Open theme folder</source>
        <translation>Відкрити теку тем</translation>
    </message>
</context>
<context>
    <name>PalettesDialog</name>
    <message>
        <location filename="../palettes.ui" line="14"/>
        <location filename="../palettes.ui" line="20"/>
        <source>Palettes</source>
        <translation>Палітри</translation>
    </message>
    <message>
        <location filename="../palettes.ui" line="33"/>
        <source>Filter...</source>
        <translation>Фільтр...</translation>
    </message>
    <message>
        <location filename="../palettes.ui" line="43"/>
        <source>&amp;Remove</source>
        <translation>&amp;Вилучити</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="61"/>
        <source>LXQt Appearance Configuration</source>
        <translation>Налаштування вигляду LXQt</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="74"/>
        <source>Widget Style</source>
        <translation>Стиль віджетів</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="83"/>
        <source>Icons Theme</source>
        <translation>Тема піктограм</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="92"/>
        <source>LXQt Theme</source>
        <translation>Тема LXQt</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="100"/>
        <source>Font</source>
        <translation>Шрифт</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="110"/>
        <source>Cursor</source>
        <translation>Курсор</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="117"/>
        <source>GTK Style</source>
        <translation>GTK-стиль</translation>
    </message>
</context>
<context>
    <name>StyleConfig</name>
    <message>
        <location filename="../styleconfig.ui" line="45"/>
        <source>Widget Style</source>
        <translation>Стиль віджетів</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="75"/>
        <source>Qt Palette</source>
        <translation>Палітра Qt</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="89"/>
        <source>Some Qt styles may ignore these colors.</source>
        <translation>Деякі стилі Qt можуть ігнорувати ці кольори.</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="114"/>
        <source>Window:</source>
        <translation>Вікно:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="124"/>
        <source>View:</source>
        <translation>Вигляд:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="134"/>
        <source>Selection:</source>
        <translation>Вибір:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="144"/>
        <source>Tooltip:</source>
        <translation>Підказка:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="158"/>
        <source>Link:</source>
        <translation>Посилання:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="178"/>
        <source>Window Text:</source>
        <translation>Текст вікна:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="188"/>
        <source>View Text:</source>
        <translation>Текст перегляду:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="198"/>
        <source>Selected Text:</source>
        <translation>Виділений текст:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="208"/>
        <source>Tooltip Text:</source>
        <translation>Текст підказки:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="222"/>
        <source>Visited Link:</source>
        <translation>Відвідане посилання:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="254"/>
        <source>&amp;Save Palette</source>
        <translation>&amp;Зберегти палітру</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="261"/>
        <source>&amp;Load Palette</source>
        <translation>З&amp;авантажити палітру</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="281"/>
        <source>&amp;Default Palette</source>
        <translation>&amp;Типова палітра</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="296"/>
        <location filename="../styleconfig.ui" line="306"/>
        <location filename="../styleconfig.ui" line="338"/>
        <location filename="../styleconfig.ui" line="348"/>
        <location filename="../styleconfig.ui" line="380"/>
        <source>May be overridden by Qt style or app</source>
        <translation>Може бути перевизначено стилем Qt або застосунком</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="299"/>
        <source>Toolbar button style:</source>
        <translation>Стиль кнопок панелі інструментів:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="310"/>
        <source>Only display the icon</source>
        <translation>Показувати лише піктограму</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="315"/>
        <source>Only display the text</source>
        <translation>Показувати лише текст</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="320"/>
        <source>The text appears beside the icon</source>
        <translation>Текст з&apos;являється поруч з піктограмою</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="325"/>
        <source>The text appears under the icon</source>
        <translation>Текст під піктограмою</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="330"/>
        <source>Default</source>
        <translation>Типово</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="341"/>
        <source>Toolbar icon size:</source>
        <translation>Розмір піктограми на панелі інструментів:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="352"/>
        <source>16</source>
        <translation>16</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="357"/>
        <source>22</source>
        <translation>22</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="362"/>
        <source>24</source>
        <translation>24</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="367"/>
        <source>32</source>
        <translation>32</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="372"/>
        <source>48</source>
        <translation>48</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="383"/>
        <source>Activate item on single click</source>
        <translation>Активувати одним натисканням</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="63"/>
        <source>Qt Style:</source>
        <translation>Стиль Qt:</translation>
    </message>
    <message>
        <location filename="../styleconfig.cpp" line="330"/>
        <location filename="../styleconfig.cpp" line="340"/>
        <source>Save Palette</source>
        <translation>Зберегти палітру</translation>
    </message>
    <message>
        <location filename="../styleconfig.cpp" line="330"/>
        <source>Palette name:</source>
        <translation>Назва палітри:</translation>
    </message>
    <message>
        <location filename="../styleconfig.cpp" line="341"/>
        <source>A palette with the same name exists.
Do you want to replace it?</source>
        <translation>Палітра з такою назвою вже існує.
Бажаєте її замінити?</translation>
    </message>
    <message>
        <location filename="../styleconfig.cpp" line="484"/>
        <source>Remove Palettes</source>
        <translation>Вилучити палітри</translation>
    </message>
    <message>
        <location filename="../styleconfig.cpp" line="485"/>
        <source>Do you really want to remove selected palette(s)?
Root palettes will remain intact if existing.</source>
        <translation>Ви дійсно хочете вилучити вибрані палітри?
Кореневі палітри залишаться недоторканими, якщо вони є.</translation>
    </message>
</context>
</TS>
